@@ -1705,7 +1705,7 @@ bool DiffTextWindowFrame::eventFilter( TQObject* o, TQEvent* e )
       /* The following lines work for TQt>4.1 but not for 4.0.x*/
       /*if ( d->mimeData()->hasUrls() )
       {
-         TQList<TQUrl> lst = d->mimeData()->urls();
+         TQPtrList<TQUrl> lst = d->mimeData()->urls();
          if ( !lst.empty() )
          {
             static_cast<TQLineEdit*>(o)->setText( lst[0].toLocalFile() );
