@@ -31,6 +31,7 @@ public:
    FileAccess();
    ~FileAccess();
    FileAccess( const TQString& name, bool bWantToWrite=false ); // name: local file or dirname or url (when supported)
+   FileAccess( const TQString& workingDir, const TQString& name, bool bWantToWrite=false ); // name: local file or dirname or url (when supported)
    void setFile( const TQString& name, bool bWantToWrite=false );
 
    bool isValid() const;
@@ -101,6 +102,7 @@ private:
    bool m_bHidden;
    long m_fileType; // for testing only
 
+   TQString m_workingDir;
    TQString m_linkTarget;
    TQString m_user;
    TQString m_group;
