@@ -34,8 +34,8 @@
 #include <tqcursor.h>
 
 
-#include <kfiledialog.h>
-#include <klocale.h>
+#include <tdefiledialog.h>
+#include <tdelocale.h>
 
 // OpenDialog **************************************************************
 
@@ -557,7 +557,7 @@ void RegExpTester::slotRecalc()
    if ( ! bSuccess )
    {
       m_pHistoryEntryStartMatchResult->setText( i18n("Opening and closing parentheses don't match in regular expression.") );
-      m_pHistorySortKeyResult->setText( i18n("") );
+      m_pHistorySortKeyResult->setText( "" );
       return;
    }
    TQRegExp historyEntryStartRegExp = m_pHistoryEntryStartRegExpEdit->text();
@@ -572,7 +572,7 @@ void RegExpTester::slotRecalc()
    else
    {
       m_pHistoryEntryStartMatchResult->setText( i18n("Match failed.") );
-      m_pHistorySortKeyResult->setText( i18n("") );
+      m_pHistorySortKeyResult->setText( "" );
    }
 }
 
